# Local Connect Python

Local Connect Python is a Python library designed to facilitate communication between clients and servers using TCP with IPV4 to only connect through the same wifi. This library provides implementations for paragraph-based and single-character communication, along with utility functions to support these operations.

## Features

- **Paragraph Clip Communication**: Includes both client and server implementations for paragraph-based communication.
- **Single Character Communication**: Includes both client and server implementations for single-character communication.


## Installation

Install the library using pip:
```bash
pip install local-connect
```

## Usage

Read about functions' name:
```bash
local-connect
```

Read more detail about a function:
```bash
local-connect [FUNCTION] --help 
```
## Contact

For any inquiries or issues, please contact the repository owner at [truongbaan](https://github.com/truongbaan).